summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autocomplete/autocomplete_edit.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-03 22:17:11 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-03 22:17:11 +0000
commitb76ac717179aa1e2c4425783a2386b7fb4b9535c (patch)
tree74ed8bb871877927767deef1fcd4b615aedb6978 /chrome/browser/autocomplete/autocomplete_edit.h
parent38ba5bd7a0c7770e95aea6619174a953e5d92796 (diff)
downloadchromium_src-b76ac717179aa1e2c4425783a2386b7fb4b9535c.zip
chromium_src-b76ac717179aa1e2c4425783a2386b7fb4b9535c.tar.gz
chromium_src-b76ac717179aa1e2c4425783a2386b7fb4b9535c.tar.bz2
autocomplete: Move AutocompleteEditView/autocomplete_edit_view.* to ui/omnibox directory.
- Rename AutocompleteEditView to OmniboxView. - Move autocomplete_edit_view.* to omnibox_view.* BUG=80186 TEST=None R=pkasting@chromium.org Review URL: http://codereview.chromium.org/6912026 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@83977 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autocomplete/autocomplete_edit.h')
-rw-r--r--chrome/browser/autocomplete/autocomplete_edit.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/chrome/browser/autocomplete/autocomplete_edit.h b/chrome/browser/autocomplete/autocomplete_edit.h
index 620caeb..3b40f7b 100644
--- a/chrome/browser/autocomplete/autocomplete_edit.h
+++ b/chrome/browser/autocomplete/autocomplete_edit.h
@@ -19,10 +19,10 @@
class AutocompleteController;
class AutocompleteEditController;
class AutocompleteEditModel;
-class AutocompleteEditView;
class AutocompletePopupModel;
class AutocompleteResult;
class InstantController;
+class OmniboxView;
class Profile;
class SkBitmap;
class TabContentsWrapper;
@@ -55,7 +55,7 @@ class AutocompleteEditController {
// status of any keyword- or hint-related state.
virtual void OnChanged() = 0;
// Called when the selection of the AutocompleteEditView changes.
virtual void OnSelectionBoundsChanged() = 0;
// Called whenever the user starts or stops an input session (typing,
@@ -100,7 +100,7 @@ class AutocompleteEditModel : public AutocompleteControllerDelegate {
const bool is_keyword_hint;
};
- AutocompleteEditModel(AutocompleteEditView* view,
+ AutocompleteEditModel(OmniboxView* view,
AutocompleteEditController* controller,
Profile* profile);
~AutocompleteEditModel();
@@ -318,9 +318,9 @@ class AutocompleteEditModel : public AutocompleteControllerDelegate {
const string16& keyword,
bool is_keyword_hint);
// Called by the AutocompleteEditView after something changes, with details
// about what state changes occured. Updates internal state, updates the
// popup if necessary, and returns true if any significant changes occurred.
// If |allow_keyword_ui_change| is false then the change should not affect
// keyword ui state, even if the text matches a keyword exactly. This value
// may be false when the user is composing a text with an IME.
@@ -439,7 +439,7 @@ class AutocompleteEditModel : public AutocompleteControllerDelegate {
scoped_ptr<AutocompleteController> autocomplete_controller_;
- AutocompleteEditView* view_;
+ OmniboxView* view_;
AutocompletePopupModel* popup_;
@@ -55,7 +55,7 @@ class AutocompleteEditController {
// status of any keyword- or hint-related state.
virtual void OnChanged() = 0;
- // Called when the selection of the AutocompleteEditView changes.
+ // Called when the selection of the OmniboxView changes.
virtual void OnSelectionBoundsChanged() = 0;
// Called whenever the user starts or stops an input session (typing,
@@ -318,9 +318,9 @@ class AutocompleteEditModel : public AutocompleteControllerDelegate {
const string16& keyword,
bool is_keyword_hint);
- // Called by the AutocompleteEditView after something changes, with details
- // about what state changes occured. Updates internal state, updates the
- // popup if necessary, and returns true if any significant changes occurred.
+ // Called by the OmniboxView after something changes, with details about what
+ // state changes occured. Updates internal state, updates the popup if
+ // necessary, and returns true if any significant changes occurred.
// If |allow_keyword_ui_change| is false then the change should not affect
// keyword ui state, even if the text matches a keyword exactly. This value